==> ackee-frontend-toolkit-0.13.0.tgz: package/es/modules/forms/stories/fields.story.js <==
import 'babel-polyfill';
import React from 'react';
import { Provider } from 'react-redux';
import { reducer as form } from 'redux-form';
import moment from 'moment';

import { storiesOf } from '@storybook/react';

import { TextField, TextAreaField, NumberField, SelectField, DatePickerField, TimePickerField, CheckboxGroupField, RadioField, SwitchField, SliderField } from '..';

import configureStore from '../../../../stories/configureStore';

import Form from './Form';

import './fields.story.scss';

var reducers = {
    form: form
};

var store = configureStore({}, reducers);

storiesOf('Modules|forms/FormFields/Text', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            null,
            story()
        )
    );
}).add('TextField', function () {
    return React.createElement(TextField, { name: 'textField', label: 'Text field' });
}).add('TextField: type password', function () {
    return React.createElement(TextField, { name: 'passwordField', type: 'password', label: 'Password field' });
}).add('TextAreaField', function () {
    return React.createElement(TextAreaField, { name: 'textAreaField', label: 'Textarea field' });
});

storiesOf('Modules|forms/FormFields/Number', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            null,
            story()
        )
    );
}).add('NumberField', function () {
    return React.createElement(NumberField, { name: 'numberField', label: 'Number field' });
});

storiesOf('Modules|forms/FormFields/Select', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { multiSelectField: ['5', '6'] } },
            story()
        )
    );
}).add('SelectField', function () {
    return React.createElement(SelectField, {
        name: 'selectField',
        label: 'Select field',
        placeholder: 'Select a value',
        options: Array.from(Array(10).keys()).map(function (index) {
            return {
                value: index,
                label: 'Option #' + index,
                key: index
            };
        })
    });
}).add('SelectField: multiple values', function () {
    return React.createElement(SelectField, {
        name: 'multiSelectField',
        label: 'Multple value Select field',
        mode: 'multiple',
        options: Array.from(Array(10).keys()).map(function (index) {
            return {
                value: index,
                label: 'Option #' + index,
                key: index
            };
        })
    });
});

storiesOf('Modules|forms/FormFields/Checkbox', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { checkboxGroupField: ['selected'] } },
            story()
        )
    );
}).add('CheckboxGroupField', function () {
    return React.createElement(CheckboxGroupField, {
        name: 'checkboxGroupField',
        label: 'Checkbox group field',
        options: [{
            label: 'Selected box',
            value: 'selected'
        }, {
            label: 'Disabled box',
            value: 'disabled',
            disabled: true
        }, {
            label: 'Unselected box',
            value: 'unSelected'
        }]
    });
});

storiesOf('Modules|forms/FormFields/Radio', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { radioField: 1 } },
            story()
        )
    );
}).add('RadioField', function () {
    return React.createElement(RadioField, {
        name: 'checkboxField',
        label: 'Select field',
        options: [{
            label: 'First',
            value: 1
        }, {
            label: 'Second',
            value: 2,
            disabled: true
        }, {
            label: 'Third',
            value: 3
        }]
    });
});

storiesOf('Modules|forms/FormFields/Switch', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { checkedSwitchField: true } },
            story()
        )
    );
}).add('SwitchField', function () {
    return React.createElement(SwitchField, { name: 'switchField', label: 'Switch field' });
}).add('CheckedSwitchField', function () {
    return React.createElement(SwitchField, { name: 'checkedSwitchField', label: 'Checked switch field', checkedChildren: '+', unCheckedChildren: '-' });
});

storiesOf('Modules|forms/FormFields/Slider', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { sliderField: 50 } },
            story()
        )
    );
}).add('SliderField', function () {
    return React.createElement(SliderField, { name: 'sliderField', label: 'Slider field', min: 0, max: 100 });
}).add('MarkedSliderField', function () {
    return React.createElement(SliderField, { name: 'markedSliderField', label: 'Marked slider field', min: 0, max: 100, marks: { 0: '0px', 50: '50px', 100: '100px' }, step: 5 });
});

storiesOf('Modules|forms/FormFields/DatePicker', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { datePicker: moment().toISOString() } },
            story()
        )
    );
}).add('DatePicker', function () {
    return React.createElement(DatePickerField, { name: 'datePicker', label: 'Datepicker Field', displayFormat: 'DD/mm/YYYY' });
});

storiesOf('Modules|forms/FormFields/TimePicker', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            null,
            story()
        )
    );
}).add('TimePicker', function () {
    return React.createElement(TimePickerField, { name: 'timePicker', label: 'Timepicker Field', displayFormat: 'H:mm:ss' });
});

==> ackee-frontend-toolkit-0.16.1.tgz: package/es/modules/forms/stories/fields.story.js <==
import 'babel-polyfill';
import React from 'react';
import { IntlProvider } from 'react-intl';
import { Provider } from 'react-redux';
import { reducer as form } from 'redux-form';
import moment from 'moment';

import { storiesOf } from '@storybook/react';

import { TextField, TextAreaField, NumberField, SelectField, DatePickerField, TimePickerField, CheckboxGroupField, RadioField, SwitchField, SliderField } from '..';

import configureStore from '../../../../stories/configureStore';

import Form from './Form';

import './fields.story.scss';

var reducers = {
    form: form
};

var store = configureStore({}, reducers);

storiesOf('Modules|forms/FormFields/Text', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            null,
            story()
        )
    );
}).add('TextField', function () {
    return React.createElement(TextField, { name: 'textField', label: 'Text field' });
}).add('TextField: type password', function () {
    return React.createElement(TextField, {
        name: 'passwordField',
        type: 'password',
        label: 'Password field'
    });
}).add('TextAreaField', function () {
    return React.createElement(TextAreaField, { name: 'textAreaField', label: 'Textarea field' });
});

storiesOf('Modules|forms/FormFields/Number', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            null,
            story()
        )
    );
}).add('NumberField', function () {
    return React.createElement(NumberField, { name: 'numberField', label: 'Number field' });
});

storiesOf('Modules|forms/FormFields/Select', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { multiSelectField: ['5', '6'] } },
            story()
        )
    );
}).add('SelectField', function () {
    return React.createElement(SelectField, {
        name: 'selectField',
        label: 'Select field',
        placeholder: 'Select a value',
        options: Array.from(Array(10).keys()).map(function (index) {
            return {
                value: index,
                label: 'Option #' + index,
                key: index
            };
        })
    });
}).add('SelectField: multiple values', function () {
    return React.createElement(SelectField, {
        name: 'multiSelectField',
        label: 'Multple value Select field',
        mode: 'multiple',
        options: Array.from(Array(10).keys()).map(function (index) {
            return {
                value: index,
                label: 'Option #' + index,
                key: index
            };
        })
    });
});

storiesOf('Modules|forms/FormFields/Checkbox', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { checkboxGroupField: ['selected'] } },
            story()
        )
    );
}).add('CheckboxGroupField', function () {
    return React.createElement(CheckboxGroupField, {
        name: 'checkboxGroupField',
        label: 'Checkbox group field',
        options: [{
            label: 'Selected box',
            value: 'selected'
        }, {
            label: 'Disabled box',
            value: 'disabled',
            disabled: true
        }, {
            label: 'Unselected box',
            value: 'unSelected'
        }]
    });
}).add('CheckboxGroupField: default values', function () {
    return React.createElement(CheckboxGroupField, {
        name: 'checkboxGroupFieldDefaultValue',
        label: 'Checkbox group field',
        defaultValue: ['val2'],
        options: [{
            label: 'Value 1',
            value: 'val1'
        }, {
            label: 'Value 2',
            value: 'val2'
        }]
    });
});

storiesOf('Modules|forms/FormFields/Radio', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { radioField: 1 } },
            story()
        )
    );
}).add('RadioField', function () {
    return React.createElement(RadioField, {
        name: 'checkboxField',
        label: 'Select field',
        options: [{
            label: 'First',
            value: 1
        }, {
            label: 'Second',
            value: 2,
            disabled: true
        }, {
            label: 'Third',
            value: 3
        }]
    });
});

storiesOf('Modules|forms/FormFields/Switch', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { checkedSwitchField: true } },
            story()
        )
    );
}).add('SwitchField', function () {
    return React.createElement(SwitchField, { name: 'switchField', label: 'Switch field' });
}).add('CheckedSwitchField', function () {
    return React.createElement(SwitchField, {
        name: 'checkedSwitchField',
        label: 'Checked switch field',
        checkedChildren: '+',
        unCheckedChildren: '-'
    });
});

storiesOf('Modules|forms/FormFields/Slider', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            Form,
            { initialValues: { sliderField: 50 } },
            story()
        )
    );
}).add('SliderField', function () {
    return React.createElement(SliderField, {
        name: 'sliderField',
        label: 'Slider field',
        min: 0,
        max: 100
    });
}).add('MarkedSliderField', function () {
    return React.createElement(SliderField, {
        name: 'markedSliderField',
        label: 'Marked slider field',
        min: 0,
        max: 100,
        marks: { 0: '0px', 50: '50px', 100: '100px' },
        step: 5
    });
});

var validateRequired = function validateRequired(fieldName) {
    return function (values, _ref) {
        var intl = _ref.intl;

        var errors = {};

        if (!values[fieldName]) {
            errors[fieldName] = intl.formatMessage({ id: 'field.validate.required' }, { name: fieldName });
        }

        return errors;
    };
};
var intlMessages = {
    'field.validate.required': 'Field {name} is required'
};

storiesOf('Modules|forms/FormFields/DatePicker', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            IntlProvider,
            { locale: 'en', messages: intlMessages },
            story()
        )
    );
}).add('DatePicker', function () {
    return React.createElement(
        Form,
        { initialValues: { datePicker: moment().toISOString() } },
        React.createElement(DatePickerField, {
            name: 'datePicker',
            label: 'Datepicker Field',
            displayFormat: 'DD/MM/YYYY'
        })
    );
}).add('localized validation', function () {
    return React.createElement(
        Form,
        { initialValues: { datePicker: moment().toISOString() }, validate: validateRequired('datePicker') },
        React.createElement(DatePickerField, {
            name: 'datePicker',
            label: 'Datepicker Field with localized validation',
            displayFormat: 'DD/MM/YYYY'
        })
    );
});

storiesOf('Modules|forms/FormFields/TimePicker', module).addDecorator(function (story) {
    return React.createElement(
        Provider,
        { store: store },
        React.createElement(
            IntlProvider,
            { locale: 'en', messages: intlMessages },
            story()
        )
    );
}).add('TimePicker', function () {
    return React.createElement(
        Form,
        null,
        React.createElement(TimePickerField, {
            name: 'timePicker',
            label: 'Timepicker Field',
            displayFormat: 'H:mm:ss'
        })
    );
}).add('localized validation', function () {
    return React.createElement(
        Form,
        { validate: validateRequired('timePicker') },
        React.createElement(TimePickerField, {
            name: 'timePicker',
            label: 'Timepicker Field with localized validation',
            displayFormat: 'H:mm:ss'
        })
    );
});
